@@ -6,7 +6,9 @@ use strict;
 
 use vars qw($VERSION @ISA);
 
-$VERSION = '0.04';
+$VERSION = '0.05';
+
+use Time::HiRes ();
 
 use Sub::Exporter -setup => {
     exports => [qw(
@@ -17,6 +19,10 @@ use Sub::Exporter -setup => {
         uuid_eq uuid_compare
 
         new_dce_uuid_string new_dce_uuid_binary
+
+        new_uuid_str new_uuid_bin new_dce_uuid_bin new_dce_uuid_str
+
+        ascending_ident
     )],
     groups => {
         default => [qw(new_uuid_string new_uuid_binary uuid_eq)],
@@ -44,6 +50,36 @@ sub uuid_to_base64 {
     MIME::Base64::encode_base64(uuid_to_binary($_[0]), '');
 }
 
+my ( $last_s, $last_us, $i ) = ( 0, 0 );
+sub ascending_ident {
+    my ( $s, $us ) = Time::HiRes::gettimeofday;
+    
+    # usec is at most 20 bits (log 2 of 1 million), so we truncate the bottom 4
+    # and use only 16 bits, with 16 more bits for a counter. decent hardware
+    # can generate several of these per usec, bot not 65 thousand per 16 usecs =)
+
+    # without $i but with a full 20 bits identifiers would be merely
+    # monotonically increasing
+
+    my $trunc_us = $us >> 4;
+
+    if ( $last_us != $trunc_us or $last_s != $s ) {
+        # the timer has increased, we can reset the counter
+        $i = 0;
+        $last_us = $trunc_us;
+        $last_s  = $s;
+    } else {
+        # increment the timer, but truncate it to 16 bits
+
+        # i've never seen it actually bigger than 2 so that gives a margin of
+        # about 5 orders of magnitude. Hopefully Moore's law doesn't get me ;-)
+
+        $i = $i+1 % 0xffff;
+    }
+
+    unpack("H*",pack("Nnn", $s, $trunc_us, $i)) . '-' . new_uuid_string();
+}
+
 __PACKAGE__
 
 __END__
@@ -52,7 +88,8 @@ __END__
 
 =head1 NAME
 
-Data::UUID::LibUUID - F<uuid.h> based UUID generation (versions 1, 2 and 4)
+Data::UUID::LibUUID - F<uuid.h> based UUID generation (versions 2 and 4
+depending on platform)
 
 =head1 SYNOPSIS
 
@@ -75,16 +112,21 @@ debian, and also works with the system F<uuid.h> on darwin.
 
 Returns a new UUID in string (dash separated hex) or binary (16 octets) format.
 
-C<$version> can be 1, 2, or 4 and defaults to 2.
+C<$version> can be either 2, or 4 and defaults to whatever the underlying
+implementation prefers.
 
 Version 1 is timestamp/MAC based UUIDs, like L<Data::UUID> provides. They
 reveal time and host information, so they may be considered a security risk.
 
 Version 2 is described here
-L<http://www.opengroup.org/onlinepubs/9696989899/chap5.htm#tagcjh_08_02_01_01>
+L<http://www.opengroup.org/onlinepubs/9696989899/chap5.htm#tagcjh_08_02_01_01>.
+It is similar to version 1 but considered more secure.
 
 Version 4 is based just on random data. This is not guaranteed to be high
-quality random data.
+quality random data, but usually is supposed to be.
+
+On MacOS X C<getpid> is called before UUID generation, to ensure UUIDs are
+unique accross forks. Behavior on other platforms may vary.
 
 =item uuid_to_binary $str_or_bin
 
@@ -132,6 +174,21 @@ also do not validate the arguments, so they can be abused as methods:
 This allows the ID generation code to be subclassed, but still keeps the hassle
 down to a minimum. DCE is UUID version two specification.
 
+=item ascending_ident
+
+Creates a lexically ascending identifier containing a UUID, high resolution
+timestamp, and a counter.
+
+This is not a UUID (it's longer), but if you can store variable length
+identifier (and exposing the system clock is not an issue) they can be used to
+create an identifier that is both universally unique, and lexically
+increasing.
+
+Note that while the identifiers are universally unique, there is no universal
+ordering (that would require synchronization), so identifiers generated on
+different machines or even different process/thread could have IDs which
+interleave.
+
 =back
 
 =head1 TODO
